@@ -179,6 +179,18 @@ formatCI <- function(ci, scale.trf=identity) {
   }
 }
 
+nice.value <- function(x, round.fun, log.scale) {
+  # Scale transform and its inverse
+  scale.trf <- if (log.scale) exp else identity
+  scale.inv <- if (log.scale) log else identity
+
+  # Round to a single significant digit, according to round.fun
+  y <- scale.trf(x)
+  p <- 10^floor(log10(abs(y)))
+  l <- scale.inv(round.fun(y / p) * p)
+  if (is.na(l) || !is.finite(l)) x else l
+}
+
 blobbogram <- function(data, id.label='Study', ci.label="Mean (95% CI)",
   left.label=NULL, right.label=NULL,
   log.scale=FALSE, xlim=NULL, styles=NULL,
@@ -187,6 +199,9 @@ blobbogram <- function(data, id.label='Study', ci.label="Mean (95% CI)",
   column.groups=NULL, column.group.labels=NULL,
   ask=dev.interactive(orNone=TRUE)) {
 
+  grid.newpage()
+  devAskNewPage(ask)
+
   grouped <- !is.null(group.labels) && isTRUE(grouped)
 
   if (is.null(styles)) {
@@ -206,16 +221,14 @@ blobbogram <- function(data, id.label='Study', ci.label="Mean (95% CI)",
   # Add default ('id') column
   columns <- c('id', columns)
   column.labels <- c(id.label, column.labels)
-
+  
   # Scale transform and its inverse
   scale.trf <- if (log.scale) exp else identity
   scale.inv <- if (log.scale) log else identity
 
   # Round to a single significant digit, according to round.fun
   nice <- function(x, round.fun) {
-    x <- scale.trf(x)
-    p <- 10^floor(log10(abs(x)))
-    scale.inv(round.fun(x / p) * p)
+    nice.value(x, round.fun, log.scale)
   }
 
   # Calculate plot range
@@ -359,17 +372,12 @@ blobbogram <- function(data, id.label='Study', ci.label="Mean (95% CI)",
 
   # Now plot each group
   for (i in 1:length(pages)) {
-    if (i > 1) {
-      if (ask) {
-        readline('Hit <Return> to see next plot:')
-      }
-    }
     page <- pages[[i]]
     if (length(page) > 0) {
       rowheights <- do.call(unit.c, lapply(page, function(grp) { grp[['rowheight']] }))
       fd <- lapply(page, function(grp) { grp[['forest.data']] })
       dev.hold()
-      grid.newpage()
+      if (i > 1) grid.newpage()
       draw.page(fd, colwidth, rowheights, ci.label,
                 grouped, columns, column.groups,
                 column.group.labels, header.labels,
